@@ -5,10 +5,9 @@
 #include "settingsdialog.h"
 #include "imagechooser.h"
 #include "highscoresdialog.h"
+#include "puzzleboard.h"
+
 
-#if defined(Q_WS_MAEMO_5) || defined(Q_WS_S60)
-#include <QAccelerometer>
-#endif
 
 namespace Ui {
     class MainWindow;
@@ -22,26 +21,30 @@ class MainWindow : public QMainWindow
     SettingsDialog *settings;
     ImageChooser *chooser;
     HighScoresDialog *highscores;
-#if defined(Q_WS_MAEMO_5) || defined(Q_WS_S60)
-    QtMobility::QAccelerometer *accelerometer;
-#endif
+    PuzzleBoard *board;
+    QPointer<QGraphicsTextItem> intro;
     bool _isPlaying;
     int _secsElapsed;
+    qreal _currentScaleRatio;
 
-    void initializeGame();
-    void endGame();
+protected:
+    bool event(QEvent *event);
+    void resizeEvent(QResizeEvent *event);
 
 public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
 private slots:
+    void on_actionHigh_scores_triggered();
     void on_actionSettings_triggered();
     void on_btnOpenImage_clicked();
     void onWon();
-    void accelerometerReadingChanged();
     void about();
-    void elapsedSecond();
+    void updateElapsedTimeLabel();
+    void initializeGame();
+    void endGame();
+    void on_btnFullscreen_clicked();
 };
 
 #endif // MAINWINDOW_H
