@@ -1,7 +1,7 @@
 #ifndef SETTINGSDIALOG_H
 #define SETTINGSDIALOG_H
 
-#include <QDialog>
+#include <QtGui>
 
 namespace Ui {
     class SettingsDialog;
@@ -10,6 +10,8 @@ namespace Ui {
 class SettingsDialog : public QDialog
 {
     Q_OBJECT
+    Ui::SettingsDialog *ui;
+    QColor _boardBackground;
 
 public:
     explicit SettingsDialog(QWidget *parent = 0);
@@ -18,15 +20,17 @@ public:
     static int rows();
     static int columns();
     static bool useAccelerometer();
+    static bool useDropShadow();
+    static QColor boardBackground();
+    static int tolerance();
 
 protected:
     void showEvent(QShowEvent *e);
 
-private:
-    Ui::SettingsDialog *ui;
-
 private slots:
+    void saveSettings();
     void on_btnClose_clicked();
+    void on_btnBoardColor_clicked();
 };
 
 #endif // SETTINGSDIALOG_H
